@@ -198,17 +198,16 @@ kinshipLR = function(..., ref = NULL, source = NULL, markers = NULL, linkageMap
     x = lapply(x, transferMarkers, from = srcPed)
   }
 
-  # By default, use all markers
-  if(is.null(markers)) {
-    nm = vapply(x, nMarkers, FUN.VALUE = 1)
-    if(!all(nm == nm[1]))
-      stop2("When `markers = NULL`, all pedigrees must have the same number of attached markers: ", nm)
-    markers = seq_len(nm[1])
-  }
-  else {
+  # Select markers
+  if(!is.null(markers))
     x = lapply(x, selectMarkers, markers)
-  }
 
+  # Check marker consistency
+  nm = vapply(x, nMarkers, FUN.VALUE = 1)
+  if(!all(nm == nm[1]))
+    stop2("The pedigrees have different markers attached.\nTip: Use `markers` and/or `source`.")
+
+  markers = seq_len(nm[1])
   if(verbose)
     cat("Number of markers: ", length(markers), "\n")
 
@@ -239,13 +238,10 @@ kinshipLR = function(..., ref = NULL, source = NULL, markers = NULL, linkageMap
 
     # If ibdsim recombination map, apply it to the attached markers
     if(inherits(linkageMap, "genomeMap") || inherits(linkageMap, "chromMap")) {
-      if(!requireNamespace("ibdsim2", quietly = TRUE))
-        stop2("The supplied `linkageMap` requires the `ibdsim2` package, which seems unavailable. Install `ibdsim2` and try again.")
       if(verbose)
         cat("Converting attached marker positions from MB to CM\n")
 
-      physMap = getMap(x[[1]])
-      linkageMap = .convertMap(physMap, linkageMap)
+      linkageMap = .convertMap(physMap = getMap(x[[1]]), linkageMap)
     }
 
     # Lump all peds, if not already done (a bit of a hack)
@@ -342,6 +338,9 @@ print.LRresult = function(x, ...) {
 # genMap = class `genomeMap`
 .convertMap = function(physMap, genMap) {
 
+  if(!requireNamespace("ibdsim2", quietly = TRUE))
+    stop2("The supplied linkage map requires the `ibdsim2` package, which seems unavailable. Install `ibdsim2` and try again.")
+
   # Split marker map by chromosome (keep original chrom order)
   chromSplit = split(physMap, factor(physMap$CHROM, levels = unique(physMap$CHROM)))
 
