@@ -18,16 +18,17 @@ test_that("kinshipLR() catches input errors", {
   expect_error(kinshipLR(s, H1=s1), "Duplicated hypothesis name")
 
   s2 = addMarker(s1)
-  expect_error(kinshipLR(s1, s2), "When `markers = NULL`, all pedigrees must have the same number of attached markers")
+  expect_error(kinshipLR(s1, s2), "The pedigrees have different")
 })
 
 test_that("kinshipLR() computes correctly in paternity case", {
   H1 = nuclearPed(fa = "fa", child = "ch") |>
-    addMarker(fa = "A/A", ch = "A/A", afreq = c(A=0.05, B=0.95))
-
+    addMarker(name = "M1", fa = "A/A", ch = "A/A", afreq = c(A=0.05, B=0.95)) |>
+    addMarker(name = "M2", fa = "A/A", ch = "A/A", afreq = c(A=0.1, B=0.9))
   H2 = list(singleton("fa"), singleton("ch"))
 
-  lr = kinshipLR(H1, H2)$LRtotal[[1]]
-  expect_equal(lr, 20)
+  expect_equal(kinshipLR(H1, H2, source = 1)$LRtotal[[1]], 20*10)
+  expect_equal(kinshipLR(H1, H2, markers = "M1")$LRtotal[[1]], 20)
+  expect_equal(kinshipLR(H1, H2, markers = -1, source = 1)$LRtotal[[1]], 10)
 })
 
