@@ -11,6 +11,16 @@ test_that("simpleSim() runs in trivial example", {
   expect_true(all(y$MARKERS[[1]] > 0))
 })
 
+test_that("simpleSim() works with explicit mutation args", {
+  x = nuclearPed(1)
+  mut = structure(c(0, 0, 1, 1), dim = c(2L, 2L), dimnames = list(c("1", "2"), c("1", "2")),
+                  model = "custom", class = "mutationMatrix")
+  mod = structure(list(female = mut, male = mut), sexEqual = TRUE,
+                  alwaysLumpable = TRUE, class = "mutationModel")
+  y = sSim(x, N=1, alleles = 1:2, afreq = c(.99, .01), mutmod = mod)
+  expect_equal(genotype(y, 1, id=3), c("2", "2"))
+})
+
 test_that("markerSim() runs in simple example", {
   x = nuclearPed(1)
   m = marker(x, '3'=1, alleles=1:2)
@@ -28,13 +38,6 @@ test_that("markerSim() works with partial with mutations", {
   expect_equal(genotype(y, 1, id=3), c("2", "2"))
 })
 
-test_that("markerSim() works with explicit mutation args", {
-  x = nuclearPed(1)
-  m = pedmut::mutationModel("custom", matrix = matrix(c(0,0,1,1), ncol=2, dimnames=list(1:2,1:2)))
-  y = mSim(x, N=1, alleles = 1:2, afreq = c(.99, .01), mutmod = m)
-  expect_equal(genotype(y, 1, id=3), c("2", "2"))
-})
-
 test_that("profileSim() keeps marker names", {
   x = nuclearPed(1)
   m = marker(x)
